# Third-Party Notices

This morphology generator is based on the work of Ondřej Tichý's thesis,
[Morphological Analyser of Old English](https://www.researchgate.net/publication/318926182_Morphological_analyser_of_old_english) (2017)
with changes made by Madeleine Thompson, who released their changes to the public domain.

The upstream morphological generator Perl code and data is (c) Ondřej Tichý, is released under the CC BY 4.0 license.  The modified Perl code itself, with Madeleine Thompson's changes, can be found at [github:madeleineth/tichy_oe_generator](https://github.com/madeleineth/tichy_oe_generator).

Changes made to the morphology generator in this repository by Christopher Malek are released under the MIT license.

All other code implemented directly by Christopher Malek, also released under
the MIT license.
